@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-use Data::Sah::Util;
+use Data::Sah;
 use JSON;
 use PHP::Serialization;
 use Plack::Request;
@@ -15,14 +15,14 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_args_from_getpost);
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our %SPEC;
 
 my $json = JSON->new->allow_nonref;
 
 sub _parse_schema {
-    Data::Sah::Util::_parse_schema(@_);
+    Data::Sah::normalize_schema($_[0]);
 }
 
 $SPEC{get_args_from_getpost} = {
@@ -206,7 +206,7 @@ Sub::Spec::GetArgs::GetPost - Get subroutine arguments from HTTP GET/POST reques
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
